@@ -354,76 +354,76 @@ test_that("Table 6 BT/Cubic Interpolation", {
 test_that("Table 1 BT/Fixed", {
   pv1 <- -f1$gr(0) / abs(f1$gr(0))
   res11 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
-  expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1)
+  expect_step(res11, x = 1e-3, f = -5e-4, df = -0.5, nfev = 1, check_grad = FALSE)
   res12 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
-  expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1)
+  expect_step(res12, x = 1e-1, f = -0.049751, df = -0.49256, nfev = 1, check_grad = FALSE)
   res13 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e1, c1 = 0.001, LS_interp = 0)
-  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1)
+  expect_step(res13, x = 1e1, f = -0.098039, df = 0.0094195, nfev = 1, check_grad = FALSE)
   res14 <- mfls(fg = f1, x = 0, pv = pv1, alpha = 1e3, c1 = 0.001, LS_interp = 0)
-  expect_step(res14, x = 31.250, f = -0.031935, df = 0.0010177, nfev = 6)
+  expect_step(res14, x = 31.250, f = -0.031935, df = 0.0010177, nfev = 6, check_grad = FALSE)
 })
 
 # Table 2
 test_that("Table 2 BT/Fixed", {
   pv2 <- -f2$gr(0) / abs(f2$gr(0))
   res21 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-3, c1 = 0.1, LS_interp = 0)
-  expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1)
+  expect_step(res21, x = 0.001, f = -1.2469e-9, df = -9.9688e-007, nfev = 1, check_grad = FALSE)
   res22 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e-1, c1 = 0.1, LS_interp = 0)
-  expect_step(res22, x = 0.1, f = -2.2181e-4, df = -0.008414, nfev = 1)
+  expect_step(res22, x = 0.1, f = -2.2181e-4, df = -0.008414, nfev = 1, check_grad = FALSE)
   res23 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e1, c1 = 0.1, LS_interp = 0)
-  expect_step(res23, x = 1.25, f = -1.8447, df = -3.4114, nfev = 4)
+  expect_step(res23, x = 1.25, f = -1.8447, df = -3.4114, nfev = 4, check_grad = FALSE)
   res24 <- mfls(fg = f2, x = 0, pv = pv2, alpha = 1e3, c1 = 0.1, LS_interp = 0)
-  expect_step(res24, x = 1.9531, f = -0.62904, df = 13.386, nfev = 10)
+  expect_step(res24, x = 1.9531, f = -0.62904, df = 13.386, nfev = 10, check_grad = FALSE)
 })
 
 # Table 3
 test_that("Table 3 BT/Fixed", {
   pv3 <- -f3$gr(0) / abs(f3$gr(0))
   res31 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-3, c1 = 0.1, LS_interp = 0)
-  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1)
+  expect_step(res31, x = 1e-3, f = 0.99999, df = -0.011857, nfev = 1, check_grad = FALSE)
   res32 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e-1, c1 = 0.1, LS_interp = 0)
-  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1)
+  expect_step(res32, x = 1e-1, f = 0.89747, df = -0.022189, nfev = 1, check_grad = FALSE)
   res33 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e1, c1 = 0.1, LS_interp = 0)
-  expect_step(res33, x = 1.25, f = 0.26493, df = 1.3789, nfev = 4)
+  expect_step(res33, x = 1.25, f = 0.26493, df = 1.3789, nfev = 4, check_grad = FALSE)
   res34 <- mfls(fg = f3, x = 0, pv = pv3, alpha = 1e3, c1 = 0.1, LS_interp = 0)
-  expect_step(res34, x = 1.9531, f = 0.95744, df = 1.9541, nfev = 10)
+  expect_step(res34, x = 1.9531, f = 0.95744, df = 1.9541, nfev = 10, check_grad = FALSE)
 })
 
 # Table 4
 test_that("Table 4 BT/Fixed", {
   pv4 <- -f4$gr(0) / abs(f4$gr(0))
   res41 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
-  expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1)
+  expect_step(res41, x = 1e-3, f = 0.99941, df = -0.29260, nfev = 1, check_grad = FALSE)
   res42 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
-  expect_step(res42, x = 1e-1, f = 0.99901, df = -4.9330e-005, nfev = 1)
+  expect_step(res42, x = 1e-1, f = 0.99901, df = -4.9330e-005, nfev = 1, check_grad = FALSE)
   res43 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e1, c1 = 0.001, LS_interp = 0)
-  expect_step(res43, x = 0.625, f = 0.99900, df = 2.2733e-006, nfev = 5)
+  expect_step(res43, x = 0.625, f = 0.99900, df = 2.2733e-006, nfev = 5, check_grad = FALSE)
   res44 <- mfls(fg = f4, x = 0, pv = pv4, alpha = 1e3, c1 = 0.001, LS_interp = 0)
-  expect_step(res44, x = 0.97656, f = 0.99902, df = 9.0755e-004, nfev = 11)
+  expect_step(res44, x = 0.97656, f = 0.99902, df = 9.0755e-004, nfev = 11, check_grad = FALSE)
 })
 
 # Table 5
 test_that("Table 5 BT/Fixed", {
   pv5 <- -f5$gr(0) / abs(f5$gr(0))
   res51 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
-  expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1)
+  expect_step(res51, x = 1e-3, f = 0.99910, df = -0.89065, nfev = 1, check_grad = FALSE)
   res52 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
-  expect_step(res52, x = 1e-1, f = 0.99144, df = 0.0039933, nfev = 1)
+  expect_step(res52, x = 1e-1, f = 0.99144, df = 0.0039933, nfev = 1, check_grad = FALSE)
   res53 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e1, c1 = 0.001, LS_interp = 0)
-  expect_step(res53, x = 0.625, f = 0.99573, df = 0.0088262, nfev = 5)
+  expect_step(res53, x = 0.625, f = 0.99573, df = 0.0088262, nfev = 5, check_grad = FALSE)
   res54 <- mfls(fg = f5, x = 0, pv = pv5, alpha = 1e3, c1 = 0.001, LS_interp = 0)
-  expect_step(res54, x = 0.97656, f = 0.99886, df = 0.0097981, nfev = 11)
+  expect_step(res54, x = 0.97656, f = 0.99886, df = 0.0097981, nfev = 11, check_grad = FALSE)
 })
 
 # Table 6
 test_that("Table 6 BT/Fixed", {
   pv6 <- -f6$gr(0) / abs(f6$gr(0))
   res61 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-3, c1 = 0.001, LS_interp = 0)
-  expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1)
+  expect_step(res61, x = 1e-3, f = 0.99945, df = -0.29888, nfev = 1, check_grad = FALSE)
   res62 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e-1, c1 = 0.001, LS_interp = 0)
-  expect_step(res62, x = 1e-1, f = 0.99817, df = -0.0089383, nfev = 1)
+  expect_step(res62, x = 1e-1, f = 0.99817, df = -0.0089383, nfev = 1, check_grad = FALSE)
   res63 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e1, c1 = 0.001, LS_interp = 0)
-  expect_step(res63, x = 0.625, f = 0.99354, df = -0.0085968, nfev = 5)
+  expect_step(res63, x = 0.625, f = 0.99354, df = -0.0085968, nfev = 5, check_grad = FALSE)
   res64 <- mfls(fg = f6, x = 0, pv = pv6, alpha = 1e3, c1 = 0.001, LS_interp = 0)
-  expect_step(res64, x = 0.97656, f = 0.99230, df = 0.071191, nfev = 11)
+  expect_step(res64, x = 0.97656, f = 0.99230, df = 0.071191, nfev = 11, check_grad = FALSE)
 })
